%bcond_without mysql
%bcond_without pgsql
%bcond_without sqlite
%bcond_without ldap
%bcond_without pcre
%bcond_without sasl
%bcond_without tls
%bcond_without ipv6
%bcond_without pflogsumm

%if 0%{?rhel} >= 6
%bcond_without lmdb
%else
%bcond_with lmdb
%endif

%if 0%{?rhel} >= 7 || 0%{?fedora} > 0
%bcond_without cdb
%bcond_without eai
%bcond_with sysvinit
%bcond_without systemd
%else
%bcond_with cdb
%bcond_with eai
%bcond_without sysvinit
%bcond_with systemd
%endif

# Allow for an unpatched build for debugging purposes.
%bcond_without patches

# Postfix requires one exlusive uid/gid and a 2nd exclusive gid for its own
# use.  Let me know if the second gid collides with another package.
# Be careful: Redhat's 'mail' user & group isn't unique!
%define postfix_uid	89
%define postfix_user	postfix
%define postfix_gid	89
%define postfix_group	postfix
%define maildrop_group	postdrop
%define maildrop_gid	90

%define postfix_config_dir	%{_sysconfdir}/postfix
%define postfix_daemon_dir	%{_libexecdir}/postfix
%define postfix_command_dir	%{_sbindir}
%define postfix_queue_dir	%{_var}/spool/postfix
%define postfix_data_dir	%{_var}/lib/postfix
%define postfix_doc_dir		%{_docdir}/%{name}-%{version}
%define postfix_sample_dir	%{postfix_doc_dir}/samples
%define postfix_readme_dir	%{postfix_doc_dir}/README_FILES
%define postfix_lib_dir		%{_prefix}/lib/postfix
%define postfix_dynamicmaps_dir	%{postfix_config_dir}/dynamicmaps.cf.d

Name: postfix
Summary: Postfix Mail Transport Agent
Version: 3.5.6
Release: 1%{?dist}
#global relc -RC1
Epoch: 2
Group: System Environment/Daemons
URL: http://www.postfix.org
License: IBM
Packager : Django <django@mailserver.guru>
Distribution: CentOS 7
Requires(post): /sbin/chkconfig
Requires(post): %{_sbindir}/alternatives
Requires(pre): %{_sbindir}/groupadd
Requires(pre): %{_sbindir}/useradd
Requires(preun): /sbin/chkconfig
Requires(preun): /sbin/service
Requires(preun): %{_sbindir}/alternatives
Requires(postun): /sbin/service

Provides: MTA smtpd smtpdaemon server(smtp)
Conflicts: postfix

Source0: ftp://ftp.porcupine.org/mirrors/postfix-release/official/postfix-%{version}%{?relc}.tar.gz
Source1: postfix-etc-init.d-postfix
Source2: postfix.service
Source3: README-Postfix-SASL-RedHat.txt
Source4: postfix.aliasesdb
Source5: postfix-chroot-update

# Sources 50-99 are upstream [patch] contributions

%define pflogsumm_ver 1.1.3

%if %{with pflogsumm}
# Postfix Log Entry Summarizer: http://jimsun.linxnet.com/postfix_contrib.html
Source53: http://jimsun.linxnet.com/downloads/pflogsumm-%{pflogsumm_ver}.tar.gz
%endif

# Sources >= 100 are config files

Source100: postfix-sasl.conf
Source101: postfix-pam.conf

# 200 and up are dynamic map config files.
Source200: dynamicmaps.cf
Source201: ldap.cf
Source202: mysql.cf
Source203: pcre.cf
Source204: pgsql.cf
Source205: sqlite.cf
Source206: lmdb.cf
Source207: cdb.cf

# Patches

Patch1: postfix-3.0.0-config.patch
Patch2: postfix-3.0.0-files.patch
Patch3: postfix-2.11.3-alternatives.patch
Patch8: postfix-3.0.0-large-fs.patch

# pflogsumm patches

Patch100: pflogsumm-1.1.3-datecalc.patch

# Optional patches - set the appropriate environment variables to include
#		     them when building the package/spec file

BuildRoot: %{_tmppath}/%{name}-%{version}-%{release}-root-%(%{__id_u} -n)

# Determine the different packages required for building postfix
BuildRequires: pkgconfig, zlib-devel, tinycdb-devel
%if 0%{?rhel} >= 7
BuildRequires: libdb-devel
%else
BuildRequires: db4-devel
%endif

%{?with_sasl:BuildRequires: cyrus-sasl-devel}
%{?with_tls:BuildRequires: openssl-devel}
%{?with_eai:BuildRequires: libicu-devel}

%description
Postfix is a Mail Transport Agent (MTA), supporting LDAP, SMTP AUTH (SASL),
TLS

%if %{with ldap}
%package ldap
Summary: LDAP Database Support for Postfix
Group: Applications/System
Requires: %{name} = %{epoch}:%{version}-%{release}
BuildRequires: openldap-devel

%description ldap
Install this package if you need support for the LDAP database type in postfix
%endif

%if %{with lmdb}
%package lmdb
Summary: LMDBtabase Support for Postfix
Group: Applications/System
Requires: %{name} = %{epoch}:%{version}-%{release}
BuildRequires: lmdb-devel

%description lmdb
Install this package if you need support for the LMDB database type in postfix
%endif

%if %{with mysql}
%package mysql
Summary: MySQL Database Support for Postfix
Group: Applications/System
Requires: %{name} = %{epoch}:%{version}-%{release}
BuildRequires: mysql-devel

%description mysql
Install this package if you need support for the MySQL database type in postfix
%endif

%if %{with pcre}
%package pcre
Summary: PCRE Database Support for Postfix
Group: Applications/System
Requires: %{name} = %{epoch}:%{version}-%{release}
BuildRequires: pcre-devel

%description pcre
Install this package if you need support for the PCRE database type in postfix
%endif

%if %{with pgsql}
%package pgsql
Summary: PostgreSQL Database Support for Postfix
Group: Applications/System
Requires: %{name} = %{epoch}:%{version}-%{release}
BuildRequires: postgresql-devel

%description pgsql
Install this package if you need support for the PostgreSQL database type in postfix
%endif

%if %{with sqlite}
%package sqlite
Summary: SQLite Database Support for Postfix
Group: Applications/System
Requires: %{name} = %{epoch}:%{version}-%{release}
BuildRequires: sqlite-devel

%description sqlite
Install this package if you need support for the SQLite database type in postfix
%endif

%if %{with cdb}
%package cdb
Summary: CDB Database Support for Postfix
Group: Applications/System
Requires: %{name} = %{epoch}:%{version}-%{release}
BuildRequires: tinycdb-devel

%description cdb
Install this package if you need support for the CDB database type in postfix
%endif

%package perl-scripts
Summary: Postfix utilities written in perl
Group: Applications/System
Requires: %{name} = %{epoch}:%{version}-%{release}
# perl-scripts introduced in 2:2.5.5-2
Obsoletes: postfix < 2:2.5.5-2
Conflicts: postfix-perl-scripts
%if %{with pflogsumm}
Provides: postfix-pflogsumm = %{epoch}:%{version}-%{release}
Obsoletes: postfix-pflogsumm < 2:2.5.5-2
%endif
%description perl-scripts
This package contains perl scripts pflogsumm and qshape.

Pflogsumm is a log analyzer/summarizer for the Postfix MTA. It is
designed to provide an over-view of Postfix activity. Pflogsumm
generates summaries and, in some cases, detailed reports of mail
server traffic volumes, rejected and bounced email, and server
warnings, errors and panics.

qshape prints Postfix queue domain and age distribution.

%prep
%setup -q -n postfix-%{version}%{?relc}
# Apply obligatory patches
%if %{with patches}
#%patch1 -p1 -b .config
%patch2 -p1 -b .files
%patch3 -p1 -b .alternatives
%patch8 -p1 -b .large-fs
%{!?with_eai: printf "smtputf8_enable = no\n" >> conf/main.cf}
%endif

%if %{with pflogsumm}
gzip -dc %{SOURCE53} | tar xf -
%if %{with patches}
pushd pflogsumm-%{pflogsumm_ver}
%patch100 -p1 -b .datecalc
popd
%endif
%endif

for f in README_FILES/TLS_{LEGACY_,}README TLS_ACKNOWLEDGEMENTS; do
	iconv -f iso8859-1 -t utf8 -o ${f}{_,} &&
		touch -r ${f}{,_} && mv -f ${f}{_,}
done

%build
CCARGS=-fstack-protector
AUXLIBS=

%ifarch s390 s390x ppc
CCARGS="${CCARGS} -fsigned-char"
%endif

%if %{with ldap}
  CCARGS="${CCARGS} -DHAS_LDAP -DLDAP_DEPRECATED=1"
  %global auxlibs_x %{?auxlibs_x} AUXLIBS_LDAP="-lldap -llber"
%endif
%if %{with lmdb}
  CCARGS="${CCARGS} -DHAS_LMDB"
  %global auxlibs_x %{?auxlibs_x} AUXLIBS_LMDB=-llmdb
%endif
%if %{with pcre}
  # -I option required for pcre 3.4 (and later?)
  CCARGS="${CCARGS} -DHAS_PCRE -I%{_includedir}/pcre"
  %global auxlibs_x %{?auxlibs_x} AUXLIBS_PCRE=-lpcre
%endif
%if %{with mysql}
  CCARGS="${CCARGS} -DHAS_MYSQL -I%{_includedir}/mysql"
  %global auxlibs_x %{?auxlibs_x} AUXLIBS_MYSQL="-L%{_libdir}/mysql -lmysqlclient -lm"
%endif
%if %{with pgsql}
  CCARGS="${CCARGS} -DHAS_PGSQL -I%{_includedir}/pgsql"
  %global auxlibs_x %{?auxlibs_x} AUXLIBS_PGSQL=-lpq
%endif
%if %{with sqlite}
  CCARGS="${CCARGS} -DHAS_SQLITE"
  %global auxlibs_x %{?auxlibs_x} AUXLIBS_SQLITE="-lsqlite3 -lpthread"
%endif
%if %{with cdb}
  CCARGS="${CCARGS} -DHAS_CDB"
  %global auxlibs_x %{?auxlibs_x} AUXLIBS_CDB=-lcdb
%endif
%if %{with sasl}
  CCARGS="${CCARGS} -DUSE_SASL_AUTH -DUSE_CYRUS_SASL -I%{_includedir}/sasl"
  AUXLIBS="${AUXLIBS} -L%{_libdir}/sasl2 -lsasl2"
  %global sasl_config_dir %{_sysconfdir}/sasl2
%endif
%if %{with tls}
  if pkg-config openssl ; then
    CCARGS="${CCARGS} -DUSE_TLS `pkg-config --cflags openssl`"
    AUXLIBS="${AUXLIBS} `pkg-config --libs openssl`"
  else
    CCARGS="${CCARGS} -DUSE_TLS -I/usr/include/openssl"
    AUXLIBS="${AUXLIBS} -lssl -lcrypto"
  fi
%endif
%if ! %{with ipv6}
  CCARGS="${CCARGS} -DNO_IPV6"
%endif
%if ! %{with eai}
  CCARGS="${CCARGS} -DNO_EAI"
%endif

CCARGS="${CCARGS} -DDEF_CONFIG_DIR=\\\"%{postfix_config_dir}\\\""
CCARGS="${CCARGS} $(getconf LFS_CFLAGS)"

AUXLIBS="${AUXLIBS} -Wl,-z,relro"

make -f Makefile.init makefiles pie=yes shared=yes dynamicmaps=yes \
     CCARGS="${CCARGS}" AUXLIBS="${AUXLIBS}" %{?auxlibs_x} DEBUG="" \
     OPT="$RPM_OPT_FLAGS -Wno-comment"

make %{?_smp_mflags}

%install
rm -rf $RPM_BUILD_ROOT
mkdir -p $RPM_BUILD_ROOT

# Move stuff around so we don't conflict with sendmail
%if %{with patches}
for x in mailq newaliases sendmail; do
    mv man/man1/$x.1 man/man1/$x.postfix.1
done
mv man/man5/aliases.5 man/man5/aliases.postfix.5
%endif

# install postfix into $RPM_BUILD_ROOT

make non-interactive-package \
       install_root=$RPM_BUILD_ROOT \
       config_directory=%{postfix_config_dir} \
       daemon_directory=%{postfix_daemon_dir} \
       command_directory=%{postfix_command_dir} \
       queue_directory=%{postfix_queue_dir} \
       data_directory=%{postfix_data_dir} \
       sendmail_path=%{postfix_command_dir}/sendmail.postfix \
       newaliases_path=%{_bindir}/newaliases.postfix \
       mailq_path=%{_bindir}/mailq.postfix \
       mail_owner=%{postfix_user} \
       setgid_group=%{maildrop_group} \
       manpage_directory=%{_mandir} \
       sample_directory=%{postfix_sample_dir} \
       readme_directory=%{postfix_readme_dir} || exit 1

# Install dynamic map files
%{__install} -d $RPM_BUILD_ROOT%{postfix_dynamicmaps_dir}
%{__install} %{SOURCE200} $RPM_BUILD_ROOT%{postfix_config_dir}
%{__install} %{SOURCE201} %{SOURCE202} %{SOURCE203} %{SOURCE204} %{SOURCE205} \
	     %{SOURCE206} %{SOURCE207} \
	     $RPM_BUILD_ROOT%{postfix_dynamicmaps_dir}

%if %{with sysvinit}
# This installs into the /etc/rc.d/init.d directory
mkdir -p $RPM_BUILD_ROOT%{_initrddir}
install -c %{SOURCE1} $RPM_BUILD_ROOT%{_initrddir}/postfix
%endif

%if %{with systemd}
# Systemd
mkdir -p %{buildroot}%{_unitdir}
install -m 644 %{SOURCE2} %{buildroot}%{_unitdir}
install -m 755 %{SOURCE4} %{buildroot}%{postfix_daemon_dir}/aliasesdb
install -m 755 %{SOURCE5} %{buildroot}%{postfix_daemon_dir}/chroot-update
%endif

install -c auxiliary/rmail/rmail $RPM_BUILD_ROOT%{_bindir}/rmail.postfix

for i in active bounce corrupt defer deferred flush incoming private saved maildrop public pid saved trace; do
    mkdir -p $RPM_BUILD_ROOT%{postfix_queue_dir}/$i
done

# install performance benchmark tools by hand
for i in smtp-sink smtp-source ; do
  install -c -m 755 bin/$i $RPM_BUILD_ROOT%{postfix_command_dir}/
  install -c -m 755 man/man1/$i.1 $RPM_BUILD_ROOT%{_mandir}/man1/
done

## RPM compresses man pages automatically.
## - Edit postfix-files to reflect this, so post-install won't get confused
##   when called during package installation.
sed -i -r "s#(/man[158]/.*.[158]):f#\1.gz:f#" $RPM_BUILD_ROOT%{postfix_config_dir}/postfix-files

cat $RPM_BUILD_ROOT%{postfix_config_dir}/postfix-files
%if %{with sasl}
# Install the smtpd.conf file for SASL support.
mkdir -p $RPM_BUILD_ROOT%{sasl_config_dir}
install -m 644 %{SOURCE100} $RPM_BUILD_ROOT%{sasl_config_dir}/smtpd.conf
%endif

mkdir -p $RPM_BUILD_ROOT%{_sysconfdir}/pam.d
install -m 644 %{SOURCE101} $RPM_BUILD_ROOT%{_sysconfdir}/pam.d/smtp.postfix

# prepare documentation
mkdir -p $RPM_BUILD_ROOT%{postfix_doc_dir}
cp -p %{SOURCE3} COMPATIBILITY LICENSE TLS_ACKNOWLEDGEMENTS TLS_LICENSE $RPM_BUILD_ROOT%{postfix_doc_dir}

mkdir -p $RPM_BUILD_ROOT%{postfix_doc_dir}/examples{,/chroot-setup}
cp -pr examples/{qmail-local,smtpd-policy} $RPM_BUILD_ROOT%{postfix_doc_dir}/examples
cp -p examples/chroot-setup/LINUX2 $RPM_BUILD_ROOT%{postfix_doc_dir}/examples/chroot-setup

cp conf/{main,bounce}.cf.default $RPM_BUILD_ROOT%{postfix_doc_dir}
sed -i 's#%{postfix_config_dir}\(/bounce\.cf\.default\)#%{postfix_doc_dir}\1#' $RPM_BUILD_ROOT%{_mandir}/man5/bounce.5
rm -f $RPM_BUILD_ROOT%{postfix_config_dir}/{TLS_,}LICENSE

find $RPM_BUILD_ROOT%{postfix_doc_dir} -type f | xargs chmod 644
find $RPM_BUILD_ROOT%{postfix_doc_dir} -type d | xargs chmod 755

%if %{with pflogsumm}
install -c -m 644 pflogsumm-%{pflogsumm_ver}/pflogsumm-faq.txt $RPM_BUILD_ROOT%{postfix_doc_dir}/pflogsumm-faq.txt
install -c -m 644 pflogsumm-%{pflogsumm_ver}/pflogsumm.1 $RPM_BUILD_ROOT%{_mandir}/man1/pflogsumm.1
install -c pflogsumm-%{pflogsumm_ver}/pflogsumm.pl $RPM_BUILD_ROOT%{postfix_command_dir}/pflogsumm
%endif

# install qshape
mantools/srctoman - auxiliary/qshape/qshape.pl > qshape.1
install -c qshape.1 $RPM_BUILD_ROOT%{_mandir}/man1/qshape.1
install -c auxiliary/qshape/qshape.pl $RPM_BUILD_ROOT%{postfix_command_dir}/qshape

# remove alias file
rm -f $RPM_BUILD_ROOT%{postfix_config_dir}/aliases

# create /usr/lib/sendmail
mkdir -p $RPM_BUILD_ROOT/usr/lib
pushd $RPM_BUILD_ROOT/usr/lib
ln -sf ../sbin/sendmail.postfix .
popd

mkdir -p $RPM_BUILD_ROOT%{_var}/lib/misc
touch $RPM_BUILD_ROOT%{_var}/lib/misc/postfix.aliasesdb-stamp

# prepare alternatives ghosts
for i in %{postfix_command_dir}/sendmail %{_bindir}/{mailq,newaliases,rmail} \
	%{_sysconfdir}/pam.d/smtp /usr/lib/sendmail \
	%{_mandir}/{man1/{mailq.1,newaliases.1},man5/aliases.5,man8/sendmail.8}
do
	touch $RPM_BUILD_ROOT$i
done

%post
%{?with_sysvinit:/sbin/chkconfig --add postfix}
%{?with_systemd:%systemd_post postfix.service}

# upgrade configuration files if necessary
%{_sbindir}/postfix set-permissions upgrade-configuration \
	daemon_directory=%{postfix_daemon_dir} \
	command_directory=%{postfix_command_dir} \
	mail_owner=%{postfix_user} \
	setgid_group=%{maildrop_group} \
	manpage_directory=%{_mandir} \
	sample_directory=%{postfix_sample_dir} \
	readme_directory=%{postfix_readme_dir} &> /dev/null

%{_sbindir}/alternatives --install %{postfix_command_dir}/sendmail mta %{postfix_command_dir}/sendmail.postfix 30 \
	--slave %{_bindir}/mailq mta-mailq %{_bindir}/mailq.postfix \
	--slave %{_bindir}/newaliases mta-newaliases %{_bindir}/newaliases.postfix \
	--slave %{_sysconfdir}/pam.d/smtp mta-pam %{_sysconfdir}/pam.d/smtp.postfix \
	--slave %{_bindir}/rmail mta-rmail %{_bindir}/rmail.postfix \
	--slave /usr/lib/sendmail mta-sendmail /usr/lib/sendmail.postfix \
	--slave %{_mandir}/man1/mailq.1.gz mta-mailqman %{_mandir}/man1/mailq.postfix.1.gz \
	--slave %{_mandir}/man1/newaliases.1.gz mta-newaliasesman %{_mandir}/man1/newaliases.postfix.1.gz \
	--slave %{_mandir}/man8/sendmail.8.gz mta-sendmailman %{_mandir}/man1/sendmail.postfix.1.gz \
	--slave %{_mandir}/man5/aliases.5.gz mta-aliasesman %{_mandir}/man5/aliases.postfix.5.gz \
	--initscript postfix

%if %{with sasl}
# Move sasl config to new location
if [ -f %{_libdir}/sasl2/smtpd.conf ]; then
	mv -f %{_libdir}/sasl2/smtpd.conf %{sasl_config_dir}/smtpd.conf
	/sbin/restorecon %{sasl_config_dir}/smtpd.conf 2> /dev/null
fi
%endif

exit 0

%pre
# Add user and groups if necessary
%{_sbindir}/groupadd -g %{maildrop_gid} -r %{maildrop_group} 2>/dev/null
%{_sbindir}/groupadd -g %{postfix_gid} -r %{postfix_group} 2>/dev/null
%{_sbindir}/groupadd -g 12 -r mail 2>/dev/null
%{_sbindir}/useradd -d %{postfix_queue_dir} -s /sbin/nologin -g %{postfix_group} -G mail -M -r -u %{postfix_uid} %{postfix_user} 2>/dev/null
exit 0

%preun
%{?with_systemd:%systemd_preun postfix.service}

if [ "$1" = 0 ]; then
%if %{with sysvinit}
    # stop postfix silently, but only if it's running
    /sbin/service postfix stop &>/dev/null
    /sbin/chkconfig --del postfix
%endif
    %{_sbindir}/alternatives --remove mta %{postfix_command_dir}/sendmail.postfix
fi

exit 0

%postun
%{?with_systemd:%systemd_postun_with_restart postfix.service}

%if %{with sysvinit}
if [ "$1" != 0 ]; then
	/sbin/service postfix condrestart 2>&1 > /dev/null
fi
exit 0
%endif

%clean
rm -rf $RPM_BUILD_ROOT


%files

# For correct directory permissions check postfix-install script.
# It reads the file postfix-files which defines the ownership
# and permissions for all files postfix installs.

%defattr(-, root, root)

# Config files not part of upstream

%if %{with sasl}
%config(noreplace) %{sasl_config_dir}/smtpd.conf
%endif
%config(noreplace) %{_sysconfdir}/pam.d/smtp.postfix
%{?with_sysvinit:%attr(0755, root, root) %{_initrddir}/postfix}
%{?with_systemd:%{_unitdir}/postfix.service}
%exclude %{postfix_dynamicmaps_dir}/*.cf

# Documentation

%{postfix_doc_dir}
%if %{with pflogsumm}
%exclude %{postfix_doc_dir}/pflogsumm-faq.txt
%endif
%exclude %{postfix_readme_dir}/LDAP_README
%exclude %{postfix_readme_dir}/LMDB_README
%exclude %{postfix_readme_dir}/MYSQL_README
%exclude %{postfix_readme_dir}/PCRE_README
%exclude %{postfix_readme_dir}/PGSQL_README
%exclude %{postfix_readme_dir}/SQLITE_README
%exclude %{postfix_readme_dir}/CDB_README

# Misc files

%dir %attr(0755, root, root) %{postfix_config_dir}
%dir %attr(0755, root, root) %{postfix_dynamicmaps_dir}
%dir %attr(0755, root, root) %{postfix_daemon_dir}
%dir %attr(0755, root, root) %{postfix_queue_dir}
%dir %attr(0700, %{postfix_user}, root) %{postfix_queue_dir}/active
%dir %attr(0700, %{postfix_user}, root) %{postfix_queue_dir}/bounce
%dir %attr(0700, %{postfix_user}, root) %{postfix_queue_dir}/corrupt
%dir %attr(0700, %{postfix_user}, root) %{postfix_queue_dir}/defer
%dir %attr(0700, %{postfix_user}, root) %{postfix_queue_dir}/deferred
%dir %attr(0700, %{postfix_user}, root) %{postfix_queue_dir}/flush
%dir %attr(0700, %{postfix_user}, root) %{postfix_queue_dir}/hold
%dir %attr(0700, %{postfix_user}, root) %{postfix_queue_dir}/incoming
%dir %attr(0700, %{postfix_user}, root) %{postfix_queue_dir}/saved
%dir %attr(0700, %{postfix_user}, root) %{postfix_queue_dir}/trace
%dir %attr(0730, %{postfix_user}, %{maildrop_group}) %{postfix_queue_dir}/maildrop
%dir %attr(0755, root, root) %{postfix_queue_dir}/pid
%dir %attr(0700, %{postfix_user}, root) %{postfix_queue_dir}/private
%dir %attr(0710, %{postfix_user}, %{maildrop_group}) %{postfix_queue_dir}/public
%dir %attr(0700, %{postfix_user}, root) %{postfix_data_dir}

%attr(0644, root, root) %{_mandir}/man1/post*.1*
%attr(0644, root, root) %{_mandir}/man1/smtp*.1*
%{?with_patches:%attr(0644, root, root) %{_mandir}/man1/*.postfix.1*}
%attr(0644, root, root) %{_mandir}/man5/access.5*
%attr(0644, root, root) %{_mandir}/man5/[b-v]*.5*
%exclude %{_mandir}/man5/ldap_table.5*
%exclude %{_mandir}/man5/lmdb_table.5*
%exclude %{_mandir}/man5/mysql_table.5*
%exclude %{_mandir}/man5/pcre_table.5*
%exclude %{_mandir}/man5/pgsql_table.5*
%exclude %{_mandir}/man5/sqlite_table.5*
#%exclude %{_mandir}/man5/cdb_table.5*
%{?with_patches:%attr(0644, root, root) %{_mandir}/man5/*.postfix.5*}
%attr(0644, root, root) %{_mandir}/man8/[a-qt-v]*.8*
%attr(0644, root, root) %{_mandir}/man8/s[ch-p]*.8*

%attr(0755, root, root) %{postfix_command_dir}/smtp-sink
%attr(0755, root, root) %{postfix_command_dir}/smtp-source

%attr(0755, root, root) %{postfix_command_dir}/postalias
%attr(0755, root, root) %{postfix_command_dir}/postcat
%attr(0755, root, root) %{postfix_command_dir}/postconf
%attr(2755, root, %{maildrop_group}) %{postfix_command_dir}/postdrop
%attr(0755, root, root) %{postfix_command_dir}/postfix
%attr(0755, root, root) %{postfix_command_dir}/postkick
%attr(0755, root, root) %{postfix_command_dir}/postlock
%attr(0755, root, root) %{postfix_command_dir}/postlog
%attr(0755, root, root) %{postfix_command_dir}/postmap
%attr(0755, root, root) %{postfix_command_dir}/postmulti
%attr(2755, root, %{maildrop_group}) %{postfix_command_dir}/postqueue
%attr(0755, root, root) %{postfix_command_dir}/postsuper
%attr(0644, root, root) %config(noreplace) %{postfix_config_dir}/access
%attr(0644, root, root) %config(noreplace) %{postfix_config_dir}/canonical
%attr(0644, root, root) %config(noreplace) %{postfix_config_dir}/dynamicmaps.cf
%attr(0644, root, root) %config(noreplace) %{postfix_config_dir}/generic
%attr(0644, root, root) %config(noreplace) %{postfix_config_dir}/header_checks
%attr(0644, root, root) %config(noreplace) %{postfix_config_dir}/main.cf
%attr(0644, root, root) %config(noreplace) %{postfix_config_dir}/master.cf
%attr(0644, root, root) %config(noreplace) %{postfix_config_dir}/main.cf.proto
%attr(0644, root, root) %config(noreplace) %{postfix_config_dir}/master.cf.proto
%attr(0644, root, root) %config(noreplace) %{postfix_config_dir}/relocated
%attr(0644, root, root) %config(noreplace) %{postfix_config_dir}/transport
%attr(0644, root, root) %config(noreplace) %{postfix_config_dir}/virtual
%attr(0755, root, root) %{postfix_daemon_dir}/[^mp]*
#%attr(0644, root, root) %{postfix_daemon_dir}/main.cf
#%attr(0644, root, root) %{postfix_daemon_dir}/master.cf
%attr(0755, root, root) %{postfix_daemon_dir}/master
%attr(0755, root, root) %{postfix_daemon_dir}/pickup
%attr(0755, root, root) %{postfix_daemon_dir}/pipe
%attr(0755, root, root) %{postfix_daemon_dir}/post-install
%attr(0644, root, root) %{postfix_config_dir}/postfix-files
%attr(0755, root, root) %{postfix_daemon_dir}/postfix-script
%attr(0755, root, root) %{postfix_daemon_dir}/postfix-wrapper
%attr(0755, root, root) %{postfix_daemon_dir}/postmulti-script
%attr(0755, root, root) %{postfix_daemon_dir}/postscreen
%attr(0755, root, root) %{postfix_daemon_dir}/proxymap
%attr(0755, root, root) %{postfix_daemon_dir}/postlogd
%attr(0755, root, root) %{_bindir}/rmail.postfix
%attr(0755, root, root) %{postfix_lib_dir}/libpostfix-*.so
%if %{with patches}
#%attr(0755, root, root) %{_prefix}/lib/sendmail.postfix
#%attr(0755, root, root) %{_bindir}/mailq.postfix
#%attr(0755, root, root) %{_bindir}/newaliases.postfix
#%attr(0755, root, root) %{_sbindir}/sendmail.postfix
%{_prefix}/lib/sendmail.postfix
%{_bindir}/mailq.postfix
%{_bindir}/newaliases.postfix
%{_sbindir}/sendmail.postfix
%attr(0755, root, root) %{_libexecdir}/postfix/postfix-tls-script

%endif

%ghost %{_sysconfdir}/pam.d/smtp

%ghost %{_mandir}/man1/mailq.1.gz
%ghost %{_mandir}/man1/newaliases.1.gz
%ghost %{_mandir}/man5/aliases.5.gz
%ghost %{_mandir}/man8/sendmail.8.gz

%ghost %attr(0755, root, root) %{_bindir}/mailq
%ghost %attr(0755, root, root) %{_bindir}/newaliases
%ghost %attr(0755, root, root) %{_bindir}/rmail
%ghost %attr(0755, root, root) %{_sbindir}/sendmail
%ghost %attr(0755, root, root) %{_prefix}/lib/sendmail

%ghost %attr(0644, root, root) %{_var}/lib/misc/postfix.aliasesdb-stamp

%if ! %{with patches}
%config(noreplace) %{postfix_config_dir}/*.default
%config(noreplace) %{postfix_config_dir}/makedefs.out
%{_prefix}/lib/sendmail.postfix
%{_bindir}/mailq.postfix
%{_bindir}/newaliases.postfix
%{_sbindir}/sendmail.postfix
%{_mandir}/man1/sendmail.1.gz
%endif

%if %{with ldap}
%files ldap
%defattr(-, root, root)
%attr(0755, root, root) %{postfix_lib_dir}/postfix-ldap.so
%attr(0644, root, root) %config(noreplace) %{postfix_dynamicmaps_dir}/ldap.cf
%doc %attr(0644, root, root) %{postfix_readme_dir}/LDAP_README
%doc %attr(0644, root, root) %{_mandir}/man5/ldap_table.5*
%endif


%if %{with lmdb}
%files lmdb
%defattr(-, root, root)
%attr(0755, root, root) %{postfix_lib_dir}/postfix-lmdb.so
%attr(0644, root, root) %config(noreplace) %{postfix_dynamicmaps_dir}/lmdb.cf
%doc %attr(0644, root, root) %{postfix_readme_dir}/LMDB_README
%doc %attr(0644, root, root) %{_mandir}/man5/lmdb_table.5*
%endif


%if %{with mysql}
%files mysql
%defattr(-, root, root)
%attr(0755, root, root) %{postfix_lib_dir}/postfix-mysql.so
%attr(0644, root, root) %config(noreplace) %{postfix_dynamicmaps_dir}/mysql.cf
%doc %attr(0644, root, root) %{postfix_readme_dir}/MYSQL_README
%doc %attr(0644, root, root) %{_mandir}/man5/mysql_table.5*
%endif

%if %{with pcre}
%files pcre
%defattr(-, root, root)
%attr(0755, root, root) %{postfix_lib_dir}/postfix-pcre.so
%attr(0644, root, root) %config(noreplace) %{postfix_dynamicmaps_dir}/pcre.cf
%doc %attr(0644, root, root) %{postfix_readme_dir}/PCRE_README
%doc %attr(0644, root, root) %{_mandir}/man5/pcre_table.5*
%endif

%if %{with pgsql}
%files pgsql
%defattr(-, root, root)
%attr(0755, root, root) %{postfix_lib_dir}/postfix-pgsql.so
%attr(0644, root, root) %config(noreplace) %{postfix_dynamicmaps_dir}/pgsql.cf
%doc %attr(0644, root, root) %{postfix_readme_dir}/PGSQL_README
%doc %attr(0644, root, root) %{_mandir}/man5/pgsql_table.5*
%endif


%if %{with sqlite}
%files sqlite
%defattr(-, root, root)
%attr(0755, root, root) %{postfix_lib_dir}/postfix-sqlite.so
%attr(0644, root, root) %config(noreplace) %{postfix_dynamicmaps_dir}/sqlite.cf
%doc %attr(0644, root, root) %{postfix_readme_dir}/SQLITE_README
%doc %attr(0644, root, root) %{_mandir}/man5/sqlite_table.5*
%endif


%if %{with cdb}
%files cdb
%defattr(-, root, root)
%attr(0755, root, root) %{postfix_lib_dir}/postfix-cdb.so
%attr(0644, root, root) %config(noreplace) %{postfix_dynamicmaps_dir}/cdb.cf
%doc %attr(0644, root, root) %{postfix_readme_dir}/CDB_README
#%doc %attr(0644, root, root) %{_mandir}/man5/cdb_table.5*
%endif


%files perl-scripts
%defattr(-, root, root)
%attr(0755, root, root) %{postfix_command_dir}/qshape
%attr(0644, root, root) %{_mandir}/man1/qshape*
%if %{with pflogsumm}
%doc %{postfix_doc_dir}/pflogsumm-faq.txt
%attr(0644, root, root) %{_mandir}/man1/pflogsumm.1.gz
%attr(0755, root, root) %{postfix_command_dir}/pflogsumm
%endif

%changelog
* Mon Aug 1 2020 Django <django@mailserver.guru> - 2:3.5.6-1
 - Bugfix (introduced: Postfix 3.5.5): part of a memory leak
   fix was backported to the wrong place. File: tls/tls_misc.c.
   The Postfix 3.5.5 workaround did not explicitly override
   the system-wide OpenSSL configuration of allowed TLS protocol
   versions, for sessions where the remote SMTP client sends
   SNI. It's better to be safe than sorry. File: tls/tls_server.c.
 - Workaround for distros that override Postfix protocol
   settings in a system-wide OpenSSL configuration file, causing
   interoperability problems after an OS update. File:
   tls/tls_client.c, tls/tls_server.c.
 - Bugfix (introduced: Postfix 3.0): 4kbyte per session memory
   leak in the Postfix TLS library, found during tests. File:
   tls/tls_misc.c.
 - Bugfix (introduced: Postfix 3.0): minor memory leaks in the
   Postfix TLS library, found during tests. File: tls/tls_misc.c.
 - Bugfix (introduced: Postfix 2.11): The Postfix smtp(8)
   client did not send the right SNI name when the TLSA base
   domain was a secure CNAME expansion of the MX hostname (or
   non-MX nexthop domain). Domains with CNAME expanded MX hosts
   are not conformant with RFC5321, and so are rare. Even more
   rare are MX hosts with TLSA records for their CNAME expansion.
   For this to matter, the remote SMTP server would also have
   to select its certificate based on the SNI name in such a
   way that the original MX host would yield a different
   certificate. Among the ~2 million hosts in the DANE survey,
   none meet the conditions for returning a different certificate
   for the expanded CNAME. Therefore, sending the correct SNI
   name should not break existing mail flows. Fixed by Viktor
   Dukhovni. File: src/tls/tls_client.c.
 - Bugfix (introduced: Postfix 3.4): SMTP over TLS connection
   reuse was broken for configurations that use explicit trust
   anchors. Reported by Thorsten Habich. Fixed by calling DANE
   initialization unconditionally (WTF). File: tlsproxy/tlsproxy.c.
 - Bugfix (introduced: Postfix 3.4): SMTP over TLS connection
   reuse was broken for configurations that use explicit trust
   anchors. Reported by Thorsten Habich. Cause: the tlsproxy
   client was sending a zero certificate length. File:
   tls/tls_proxy_client_print.c.
 - Bugfix (introduced: Postfix 3.4): the connection_reuse
   attribute in smtp_tls_policy_maps resulted in an "invalid
   attribute name" error. Fix by Thorsten Habich. File:
   smtp/smtp_tls_policy.c.
 - Bugfix (introduced: Postfix 3.4): in the Postfix SMTP server,
   the SNI callback reported an error when it was called a
   second time. This happened after the server-side TLS engine
   sent a TLSv1.3 HelloRetryRequest (HRR) to a remote SMTP
   client. Reported by JÃ¡n MÃ¡tÃ©, fixed by Viktor Dukhovni.
   File: tls/tls_misc.c.
 - Bugfix (introduced: Postfix 3.1): "postfix tls deploy-server-cert"
   did not handle a missing optional argument. File:
   conf/postfix-tls-script.

* Mon May 18 2020 Django <django@mailserver.guru> - 2:3.5.2-1
 - Bugfix (introduced: Postfix 2.2): a TLS error for a PostgreSQL
   client caused a false 'lost connection' error for an SMTP
   over TLS session in the same Postfix process. Reported by
   Alexander Vasarab, diagnosed by Viktor Dukhovni. File:
   tls/tls_bio_ops.c.
 - Bugfix (introduced: Postfix 2.8): a TLS error for one TLS
   session may cause a false 'lost connection' error for a
   concurrent TLS session in the same tlsproxy process. File:
   tlsproxy/tlsproxy.c.
 - Noise suppression: avoid "SSL_Shutdown:shutdown while in
   init" warnings. File: tls/tls_session.c.
 - Bitrot: avoid U_FILE_ACCESS_ERROR after chroot(), by
   initializing the ICU library before making the chroot()
   call. Files: util/midna_domain.[hc], global/mail_params.c.
 - Bugfix (introduced: Postfix 3.5): maillog_file_rotate_suffix
   default value used the minute instead of the month. Reported
   by Larry Stone. Files: conf/postfix-tls-script,
   proto/MAILLOG_README.html, proto/postconf.proto.
   global/mail_params.h, postfix/postfix.c.
 - Noise suppression: shut up a compiler that special-cases
   string literals. Viktor Dukhovni. File smtpd/smtpd_check.c.
 - Security: disable DANE support on Alpine Linux because
   libc-musl provides no indication whether DNS responses are
   authentic. This broke DANE support without a clear explanation.
   File: makedefs.
 - Noise suppression: shut up a compiler that special-cases
   string literals. Viktor Dukhovni. File milter/milter.c.
 - Bugfix: segfault in the tlsproxy client role when the server
   role was disabled. This typically happens on systems that
   do not receive mail, after configuring connection reuse for
   outbound TLS. Found during program maintenance. File:
   tlsproxy/tlsproxy.c.

* Tue Apr 21 2020 Django <django@mailserver.guru> - 2:3.5.1-1
 - Workaround for broken builds after an incompatible change
   in GCC 10. Files: makedefs, Makefile.in.
 - Workaround for broken DANE support after an incompatible
   change in GLIBC 2.31. This avoids the need for new options
   in /etc/resolv.conf. Files: dns/dns.h, dns/dns_lookup.c.

* Fri Apr 17 2020 Django <django@mailserver.guru> - 2:3.5.0-1
 - Removed the issuer_cn and subject_cn matches from
   check_ccert_access. Files: smtpd/smtpd_check.c,
   proto/postconf.proto.
 - Usability: the Postfix SMTP server now logs a warning when
   a configuration requests access control by client certificate,
   but "smtpd_tls_ask_clientcert = no".  Files: proto/postconf.proto,
   smtpd/smtpd_check.c.

* Sun Mar 15 2020 Django <django@mailserver.guru> - 2:3.4.10-1
 - Bugfix (introduced: Postfix 2.3): panic with Postfix
   multi-Milter configuration during MAIL FROM. Milter client
   state was not properly reset after one of the Milters failed.
   Reported by WeiYu Wu.
 - Bugfix (introduced: Postfix 2.5): the Milter connect event
   macros were evaluated before the Milter connection itself
   had been negotiated. Problem reported by David Baergin.
   Files: milter/milter.h, milter/milter.c, milter/milter8.c

* Mon Dec 16 2019 Django <django@mailserver.guru> - 2:3.4.9-1
 - Bugfix (introduced: Postfix 3.1): support for
   smtp_dns_resolver_options was broken while adding support
   for negative DNS response caching in postscreen. Postfix
   was inadvertently changed to call res_query() instead of
   res_search(). Reported by Jaroslav Skarvada. File:
   dns/dns_lookup.c.
 - Bugfix (introduced: Postfix 3.0): sanitize server responses
   before storing them in the verify database, to avoid Postfix
   warnings about malformed UTF8. File: verify/verify.c.
 - Usability: the parser for key/certificate chain files
   rejected inputs that contain an EC PARAMETERS object. While
   this is technically correct (the documentation says what
   types are allowed) this is surprising behavior because the
   legacy cert/key parameters will accept such inputs. For
   now, the parser skips object types that it does not know
   about for usability, and logs a warning because ignoring
   inputs is not kosher. Viktor and Wietse. File: tls/tls_certkey.c.
 - Bugfix (introduced: Postfix 2.8): don't gratuitously enable
   all after-220 tests when only one such test is enabled.
   This made selective tests impossible with 'good' clients.
   File: postscreen/postscreen_smtpd.c.
 - Bugfix: the 20180903 postscreen fix for a misleading
   "PIPELINING after BDAT" warning looked at the wrong variable.
   The warning now says "BDAT without valid RCPT", and the
   error is no longer treated as a command PIPELINING error
   (but sending BDAT is still a client error, because postscreen
   rejects all RCPT commands and does not announce PIPELINING
   support). File: postscreen/postscreen_smtpd.c.

* Mon Sep 16 2019 Django <django@mailserver.guru> - 2:3.4.8-1
 - Bugfix (introduced: Postfix 3.4): don't whitewash OpenSSL
   error results after a plaintext output error. The code could
   loop, and with some OpenSSL error results could flood the
   log with error messages (see below for a specific case).
   Problem reported by Andreas Schulze. File: tlsproxy/tlsproxy.c.
   Bitrot: don't invoke SSL_shutdown() when the SSL engine
   thinks it is processing a TLS handshake. The commit at
   https://github.com/openssl/openssl/commit/64193c8218540499984cd63cda41f3cd491f3f59
   changed the error status, incompatibly, from SSL_ERROR_NONE
   into SSL_ERROR_SSL. File: tlsproxy/tlsproxxy.c.
 - Bugfix (introduced: 20051222): the Dovecot client could
   segfault (null pointer read) or cause an SMTP server assertion
   to fail when talking to a fake Dovecot server. The client
   now logs a proper error instead. Problem reported by Tim
   Daesterhus. File: xsasl/xsasl_dovecot_server.c.
 - Workaround for poor TCP loopback performance on LINUX, where
   getsockopt(..., TCP_MAXSEG, ..) reports a TCP maximal segment
   size that is 1/2 to 1/3 of the MTU. For example, with kernel
   5.1.16-300.fc30.x86_64 the TCP client and server announce
   an mss of 65495 in the TCP handshake, but getsockopt()
   returns 32741 (less than half). As a matter of principle,
   Postfix won't turn on client-side TCP_NODELAY because that
   hides application performance bugs, and because that still
   suffers from server-side delayed ACKs. Instead, Postfix
   avoids sending "small" writes back-to-back, by choosing a
   VSTREAM buffer size that is a multiple of the reported MSS.
   This workaround bumps the multiplier from 2x to 4x. File:
   util/vstream_tweak.c.

* Fri Jul 26 2019 Django <django@mailserver.guru> - 2:3.4.7-1
 - Bugfix: the documentation said tls_fast_shutdown_enable,
   but the code said tls_fast_shutdown. Viktor Dukhovni. Changed
   the code because no-one is expected to override the default.
   File: global/mail_params.h.
 - Bugfix (introduced: Postfix 3.0): the code to reset Postfix
   SMTP server command counts was not called after a HaProxy
   handshake failure, causing stale numbers to be reported.
   The command counts are now reset in the function that reports
   the counts. File: smtpd/smtpd.c.
 
* Wed Jul 3 2019 Django <django@mailserver.guru> - 2:3.4.6-1
 - Documentation: updated the BUGS section in the smtp(8) manpage
   about TLS connection reuse. File: smtp/smtp.c.
 - Workaround for implementations that hang Postfix while
   shutting down a TLS session, until Postfix times out. With
   "tls_fast_shutdown_enable = yes" (the default), Postfix no
   longer waits for the TLS peer to respond to a TLS 'close'
   request. This is recommended with TLSv1.0 and later. Files:
   global/mail_params.h, tls/tls_session.c, and documentation.
 - Bugfix (introduced: Postfix 3.0): the code to reset Postfix
   SMTP server command counts was not called after a HaProxy
   handshake failure, causing stale numbers to be reported.
   The command counts are now reset in the function that reports
   the counts. File: smtpd/smtpd.c.

* Wed Apr 3 2019 Django <django@mailserver.guru> - 2:3.4.5-1
 - Bugfix (introduced: Postfix 3.0): LMTP connections over
   UNIX-domain sockets were cached but not reused, due to a
   cache lookup key mismatch. Therefore, idle cached connections
   could exhaust LMTP server resources, resulting in two-second
   pauses between email deliveries. This problem was investigated
   by Juliana Rodrigueiro. File: smtp/smtp_connect.c.
 - With message_size_limit=0 (which is NOT DOCUMENTED), BDAT
   chunks were always rejected as too large. File: smtpd/smtpd.c
 - Bugfix (introduced: Postfix 2.2): reject_multi_recipient_bounce
   has been producing false rejects starting with the Postfix
   2.2 smtpd_end_of_data_restrictons, and for the same reasons,
   does the same with the Postfix 3.4 BDAT command. The latter
   was reported by Andreas Schulze. File: smtpd/smtpd_check.c.

* Mon Mar 11 2019 Django <django@mailserver.guru> - 2:3.4.3-1
 - Bitrot: LINUX5s support, after some sanity checks with a
   rawhide prerelease version. Files: makedefs, util/sys_defs.h.
 - Bugfix (introduced: 20181226): broken DANE trust anchor
   file support, caused by left-over debris from the 20181226
   TLS library overhaul. Scott Kitterman. File: tls/tls_dane.c.
 - Bugfix (introduced: Postfix-1.0.1): null pointer read, while
   logging a warning after a corrupted bounce log file. File:
   global/bounce_log.c.
 - Bugfix (introduced: Postfix-2.9.0): null pointer read, while
   logging a warning after a postscreen_command_filter read
   error. File: postscreen/postscreen_smtpd.c. global/bounce_log.c

* Mon Mar 11 2019 Django <django@mailserver.guru> - 2:3.4.2-1
 - Bugfix: a reversed test broke TLS configurations that specify
   the same filename for a private key and certificate. Reported
   by Mike Kazantsev. Fix by Viktor Dukhovni. Wietse fixed the
   test. Files: tls/tls_certkey.c, tls/Makefile.in.

* Sun Mar 10 2019 Django <django@mailserver.guru> - 2:3.4.1-1
 - Bugfix: in the Postfix SMTP client, TLS wrappermode was not
   tested in tlsproxy mode. It needed some setup for buffering
   and timeouts. Problem report by Andreas Schulze. File:
   smtp/smtp_proto.c.
 - Bugfix: a reversed test broke TLS configurations that specify
   the same filename for a private key and certificate. Reported
   by Mike Kazantsev. Fix by Viktor Dukhovni. Wietse fixed the
   test. Files: tls/tls_certkey.c, tls/Makefile.in.

* Thu Jan 17 2019 Django <django@mailserver.guru> - 2:3.3.2-1
 - Bugfix (introduced: 20170617): postconf(1) command segfault
   if unable to open a Postfix database configuration file due
   to a file permission error. Report by Andreas Hasenack, fix
   by Viktor Dukhovni.  File: postconf/postconf_dbms.c.
 - Cleanup: Postfix did not support running as a PID=1 process,
   which complicated Postfix management in containers. The
   "postfix start-fg" command will now run the Postfix master
   daemon as a PID=1 process if possible. Thanks to inputs
   from Andreas Schulze, Eray Aslan, and Viktor Dukhovni.
   Files: postfix/postfix.c, master/master.c, master/master.h,
   master/master_sig.c, conf/postfix-script.
 - Bugfix (introduced: Postfix 2.11): minor memory leak when
   minting issuer certs. This affects a tiny minority of use
   cases. Viktor Dukhovni, based on a fix by Juan Altmayer
   Pizzorno for the ssl_dane library. File: tls/tls_dane.c.
 - Workaround: postconf build did not abort if the m4 command
   is not installed (on a system that does have the make
   command, the awk command, the perl command, and the C
   compiler?!).  File: postconf/extract_cfg.sh.
 - Multiple 'bit rot' fixes for OpenSSL API changes, including
   support to disable TLSv1.3, to avoid issuing multiple session
   tickets, and to allow OpenSSL >= 1.1.0 run-time micro version
   bumps without complaining about library version mismatches.
   Viktor Dukhovni. Files: proto/postconf.proto,
   proto/TLS_README.html, tls/tls.h, tls/tls_server.c,
   tls/tls_misc.c.
 - Bugfix (introduced: 3.0): smtpd_discard_ehlo_keywords could
   not disable "SMTPUTF8". because the lookup table was using
   "EHLO_MASK_SMTPUTF8" instead. File: global/ehlo_mask.c.
 - Documentation: update documentation for Postfix versions
   that support disabling TLS 1.3. File: proto/postconf.proto.
 - Improved logging of TLS 1.3 summary information, and improved
   reporting of the same info in Received: message headers.
   Viktor Dukhovni. Files: proto/FORWARD_SECRECY_README.html,
   posttls-finger/posttls-finger.c, smtpd/smtpd.c, tls/tls.h,
   tls/tls_client.c, tls/tls_misc.c, tls/tls_proxy.h,
   tls/tls_proxy_context_print.c, tls/tls_proxy_context_scan.c,
   tls/tls_server.c.

* Mon Oct 22 2018 Django <django@mailserver.guru> - 2:3.2.6-1
 - Documentation patches by Sven Neuhaus. Files:
   proto/FORWARD_SECRECY_README.html, proto/MILTER_README.html,
   proto/SMTPD_ACCESS_README.html.
 - Cleanup: missing mailbox seek-to-end error check in the
   local(8) delivery agent. File: local/mailbox.c.
   Cleanup: incorrect mailbox seek-to-end error message in the
   virtual(8) delivery agent. File: virtual/mailbox.c.
 - Licence: in addition to the historical IBM Public License
   1.0, this software is now also distributed with the more
   recent Eclipse Public License 2.0. Recipients can choose
   to take the software under the license of their choice.
   Those who are more comfortable with the IPL can continue
   with that license. File: LICENSE.
 - Cleanup: added 22 missing *_maps parameters to the default
   proxy_read_maps setting. Files: global/mail_params.h.
 - Bugfix (introduced: 20120117): postconf should scan only
   built-in or service-defined parameters for ldap, *sql, etc.
   database names. Files: postconf/postconf_user.c.
 - Bugfix (introduced: 19990302): when luser_relay specifies
   a non-existent local address, the luser_relay feature becomes
   a black hole. Reported by JĂ¸rgen Thomsen. File: local/unknown.c.
 - Bugfix (introduced: Postfix 2.8): missing tls_server_start()
   error propagation in tlsproxy(8) resulting in segfault after
   TLS handshake error. Found during code maintenance. File:
   tlsproxy/tlsproxy.c.

* Thu Dec 28 2017 Django <django@mailserver.guru> - 2:3.1.1-1
  * Cleanup: "match_list_match: permit_mynetworks: no match" after
    a SUCCESSFUL permit_mynetworks match of a client IP address was
    complicating troubleshooting.  The fix is to log additional
    context to clarify that this "no match" condition is for
    smtpd_log_access_permit_actions. File: smtpd/smtpd_check.c.
  * Documentation: typos in postfix-tls-script(1) manpage.
    line wrapping in postconf(1) manpage.
  * Bugfix (introduced: Postfix 2.6): the Milter SMFIR_CHGFROM
    (replace sender) request lost the sender_bcc_maps address.
    Fixed by moving some record keeping to the sender output
    function.  Files: cleanup/cleanup_envelope.c,
    cleanup/cleanup_addr.c, cleanup/cleanup_milter.c,
    cleanup/cleanup.h, regression tests.
  * Bugfix (introduced: Postfix 2.6): the "bad filetype"
    header_checks pattern falsely rejected Content-Mumble headers
    with ``name="example"; x-apple-part-url="example.com"''.
    Fixed by respecting the ";" separator between content
    attribute values.  Reported by Cedric Knight.  File:
    proto/header_checks.
    Portability: OpenBSD 6.0. Files: makedefs, util/sys_defs.h.

* Fri Dec 16 2016 Django <django@mailserver.guru> - 2:3.1.0-1
  * "postconf -H" support (show names without the =value).
    Initial use case: mass reversal of TLS-related main.cf
    parameters (postconf -nH | grep _tls_ | xargs postconf -X).
    This flag also works with "postconf -F" and "postconf -P".
    Added missing documentation that -h works with "postconf
    -F" and "postconf -P".  Files: postconf.c, postconf.h,
    postconf_master.c, postconf_main.c.
  - Robustness: force html2text to produce ASCII output.  File:
    mantools/html2readme.
  - Feature: "postfix tls" commands to enable opportunistic TLS
    in the Postfix SMTP client or server, or generate or replace
    Postfix SMTP server TLS private keys and server certificates.
    Viktor Dukhovni, Wietse. Files: conf/postfix-files,
    conf/postfix-script, conf/postfix-tls-script, makedefs,
    proto/INSTALL.html, proto/postconf.proto, global/mail_params.h,
    postfix/postfix.c, tls/tls_misc.c.
  - Portability: added a tls_random_source default setting for
    MacOS X. Viktor Dukhovni. File: util/sys_defs.h.
  - Cleanup: "match_list_match: permit_mynetworks: no match" after
    a SUCCESSFUL permit_mynetworks match of a client IP address was
    complicating troubleshooting.  The fix is to log additional
    context to clarify that this "no match" condition is for
    smtpd_log_access_permit_actions. File: smtpd/smtpd_check.c.

* Thu May 19 2016 Django <django@mailserver.guru> - 2:3.0.5-1
  * The "bad filetype" header_checks pattern falsely rejected 
    Content-Mumble headers with ``name="example"; 
    x-apple-part-url="example.com"''.
    Fixed by respecting the ";" separator between content
    attribute values.  Reported by Cedric Knight.  File:
    proto/header_checks.

* Sun Mar 13 2016 Django <django@mailserver.guru> - 2:3.0.4-1
- update-release
  * Documentation (introduced: Postfix 3.0): wrong paramester
    name in lmtp_address_verify_target description. File:
    proto/posconf.proto
  * Bugfix: the Milter SMFIR_CHGFROM (replace sender) request 
    lost the sender_bcc_maps address.
    Fixed by moving some record keeping to the sender output
    function.  Files: cleanup/cleanup_envelope.c,
    cleanup/cleanup_addr.c, cleanup/cleanup_milter.c,
    cleanup/cleanup.h, regression tests.

* Sat Oct 10 2015 Django <django@mailserver.guru> - 2:3.0.3-1
- fixpack-release
  * The uxtext_unquote() function had the same problem as 
    xtext_unquote(), because one was created by copying the 
    other. The Postfix SMTP server uses this function to 
    parse input for the ORCPT parameter when the remote 
    SMTP client sends SMTPUTF8 mail.
  * Unreported bug: Postfix smtpd_mumble_restrictions could 
    report an incorrect reason for failed DNS lookups. Fixed 
    by saving and restoring h_errno while evaluating the 
    result from multi-query DNS lookups.
  * The COMPATIBILITY_README text and HTML files were not 
    installed.
  * don't throttle a destination
    after opportunistic TLS failure. Viktor Dukhovni. File:
    smtp/smtp_proto.c.

* Mon Jul 20 2015 Django <django@mailserver.guru> - 2:3.0.2-1
- fixpack-release
  * With all supported Postfix releases, the default TLS 
    settings no longer enable export-grade ciphers, and no 
    longer enable the SSLv2 and SSLv3 protocols. These 
    ciphers and protocols have little if any legitimate use 
    today, and have instead become a vehicle for downgrade 
    attacks. There are no other code changes.

* Sun Apr 12 2015 Django <django@mailserver.guru> - 2:3.0.1-1
- fixpack-release
  * Build error when compiling the Postfix SMTP server with 
    SASL support but no TLS support.
  * The DNS "resource record to text" converter, used for 
    xxx_dns_reply_filter pattern matching, appended a '.' 
    to TXT record resource values.
  * The postscreen(8) manpage specified an incorrect Postfix 
    version number for the postscreen_dnsbl_timeout parameter.
  * The postfix-install script expanded macros in parameter 
    values when trying to detect parameter overrides, causing 
    unnecessary main.cf updates during "postfix start" etc.
  * Some low-level cleanup of UTF-8 string handling with no 
    visible change in behavior (besides better performance).
  * Preparation for OpenSSL 1.2 API changes.
  * The sender_dependent_relayhost_maps feature ignored the 
    relayhost setting in the case of a DUNNO lookup result. 
    It would use the recipient domain instead.

* Sun Feb 08 2015 Django <django@mailserver.guru> - 2:3.0.0-1
- Initial build 3.0.0 stable release for CentOS 7
  * SMTPUTF8 support for internationalized domain names and 
    address localparts as defined in RFC 6530 and related 
    documents. The implementation is based on code contributed 
    by Arnt Gulbrandsen and sponsored by CNNIC. SMTPUTF8 
    support is a work in progress; it is expected to be 
    completed during the Postfix 3.1 development cycle. 
    See SMTPUTF8_README for a summary of limitations.
  * Support for Postfix dynamically-linked libraries and data-
    base plugins. The implementation is based on code by 
    LaMont Jones for Debian Linux. See INSTALL for detailed 
    descriptions of the available options.
  * An OPT-IN safety net for the selective adoption of new 
    Postfix default settings. If you do nothing, the old 
    Postfix default settings *should* remain in effect 
    (complain to your downstream maintainer if that is not 
    the case). See COMPATIBILITY_README for detailed 
    descriptions of Postfix logfile messages.
  * Support for operations on multiple lookup tables. The 
    pipemap:{map1,map2...} database type implements a 
    pipeline of lookup tables where the result from one 
    lookup table becomes a query for the next table; the 
    unionmap:{map1,map2,...} database type sends the same 
    query to multiple lookup tables and concatenates their 
    results.
  * Support for pseudo-tables that make simple things easy 
    to implement. The inline:{key1=value1,key2=value2,...} 
    table avoids the need to create an external file for 
    just a few items; and the randmap{value1,value2,...} 
    table implements random selection from the specified 
    values.
  * Table-driven transformation of DNS lookup results and 
    of delivery agent status codes and messages. Typically,
    one would use a PCRE table to fix problematic DNS 
    responses or to fix the handling of delivery errors. 
    See smtp_dns_reply_filter, smtp_delivery_status_filter, 
    and similarly-named parameters for other Postfix daemons.
  * Improved configuration file syntax with support for the 
    ternary operator such as ${name?{iftrue}:{iffalse}}, 
    comparison operators such as 
    ${{expr1}==${expr2}?{iftrue}:{iffalse}}, per-Milter and 
    per-policy server timeout and other settings, master.cf 
    parameters that contain whitespace, 
    import/export_environment settings that contain whit-
    espace, and "static" table lookup results that contain 
    whitespace. Support for multiple lookup results in 
    access(5) and header/body_checks(5) tables is expected 
    to be completed in the Postfix 3.1 development cycle.
    Per-session command profiles, logged at the end of each 
    inbound SMTP session. For example, a password-guessing 
    bot is logged as "disconnect from name[addr] ehlo=1 
    auth=0/1 commands=1/2", meaning that the client sent 
    one EHLO command that worked, one AUTH command that 
    failed, and hung up without sending a QUIT command. 
    This information is always logged, and can help to 
    solve puzzles without verbose logging or network 
    sniffers.

